Package: NTLKwIEx
Type: Package
Title: Computation of NTLKwIEx Distribution Properties
Version: 0.2.0
Authors@R: c( 
  person("Mintodê Nicodème","Atchadé", role=c("aut"), email="nickpowerabc@gmail.com"),
  person("Théophile","Otodji", role=c("aut","cre"), email="otodjitheodule@gmail.com")
  )
Author: Mintodê Nicodème Atchadé [aut],
  Théophile Otodji [aut, cre]
Maintainer: Théophile Otodji <otodjitheodule@gmail.com>
Description: Implements statistical tools for analyzing, simulating, and computing properties of the New Topp-Leone Kumaraswamy Inverse Exponential (NTLKwIEx) distribution. See Atchadé M, Otodji T, and Djibril A (2024) <doi:10.1063/5.0179458> and Atchadé M, Otodji T, Djibril A, and N'bouké M (2023) <doi:10.1515/phys-2023-0151> for details.
Depends: R (>= 3.6.0), stats, dplyr, ggplot2
License: GPL-2
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.3
VignetteBuilder: knitr
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
Language: en
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-14 10:32:06 UTC; Théophile OTODJI
Repository: CRAN
Date/Publication: 2026-04-14 13:10:02 UTC
Built: R 4.5.2; ; 2026-04-14 16:39:53 UTC; unix
